sign_vectors: SageMath package for sign vectors, oriented matroids and chirotopes
=================================================================================

Description
-----------

SageMath package for sign vectors, oriented matroids and chirotopes

License
-------

GPL-3.0-or-later

Upstream Contact
----------------

https://pypi.org/project/sign-vectors/

